@@ -83,6 +83,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, topo, tree) {
 
   # line 5
   else {
+
     cc <- cc[[1]]
     cG.s <- lapply(1:d, function(x) sc.components(D[[x]], topo[[x]]))
     cG <- cG.s[[1]]
@@ -125,6 +126,7 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, topo, tree) {
       }
 
       # line 8
+
       tree$call$c.zero <- cc
       cc.s <- lapply(cG.s, function(x) {
         x[[which(unlist(lapply(x, function(y) all(cc %in% y))))]]
@@ -175,7 +177,6 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, topo, tree) {
     # line 9
     } else {
 
-      # line 10
       E.tr <- list()
       if (length(J) == 0) {
         tree$call$line <- 10
@@ -186,30 +187,34 @@ trmz <- function(y, x, P, J, domain, w.index, D, Z, topo, tree) {
           A <- subgraph.edges(A, E(A)[!to(x)], delete.vertices = FALSE)
           A <- as.matrix(get.adjacency(A))
           if (wrap.dSep(A, s[[i]], y, x) & (length(intersect(Z[[i]], x)) != 0)) {
-            P$domain <- i
-            ind <- ind + 1
+            P.new <- P
+            P.new$domain <- i
             xcapz <- intersect(Z[[i]], x)
             D.remove.xcapz <- lapply(1:d, function(x) induced.subgraph(D[[x]], v[!(v %in% xcapz)]))
             nxt <- trmz(y, setdiff(x, Z[[i]]), P, xcapz, i, W.new, D.remove.xcapz, Z, topo, list())
-            tree$branch[[ind]] <- nxt$tree
-            E.new <- nxt$P
-            W.new <- nxt$W
-            E.new <- activate.interventions(E.new, i, xcapz)
-            E.tr[[ind]] <- E.new
+            if (!is.null(nxt)) {
+              ind <- ind + 1
+              tree$branch[[ind]] <- nxt$tree
+              E.new <- nxt$P
+              W.new <- nxt$W
+              E.new <- activate.interventions(E.new, i, xcapz)
+              E.tr[[ind]] <- E.new
+            }
           }
         }
+
+        # line 11
+        if (length(E.tr) > 1) {
+          P.new <- probability(sum = TRUE, children = E.tr, weight = w.index)
+          tree$root <- P.new
+          return(list(P = P.new, W = W.new, tree = tree))
+        }
+        if (length(E.tr) == 1) {
+          tree$root <- E.tr[[1]]
+          return(list(P = E.tr[[1]], W = W.new, tree = tree))
+        }
       }
 
-      # line 11
-      if (length(E.tr) > 1) {
-        P.new = probability(sum = TRUE, children = E.tr, weight = w.index)
-        tree$root <- P.new
-        return(list(P = P.new, W = W.new, tree = tree))
-      } 
-      if (length(E.tr) == 1) {
-        tree$root <- E.tr[[1]]
-        return(list(P = E.tr[[1]], W = W.new, tree = tree))
-      }
       stop("Not transportable.", call. = FALSE)
     }
   }
